import { putNewTrk } from './trk';

declare global {
  var db: any;
  var dbReady: boolean;
}

const originalDb = globalThis.db;
const originalDateNow = globalThis.Date.now;

describe('The gpx module', () => {
  beforeEach(() => {
    globalThis.db = { put: jest.fn() };
    globalThis.Date.now = () => 0;
  });
  afterEach(() => {
    globalThis.db = originalDb;
    globalThis.Date.now = originalDateNow;
  });
  test('db.put() a new trk when required', async () => {
    putNewTrk({ gpx: 'gpxId', trk: 'trkid' });
    await expect(globalThis.db.put).toBeCalledWith({
      _id: 'gpx/gpxId/2trk/trkid',
      _rev: undefined,
      doc: {
        cmt: undefined,
        desc: undefined,
        extensions: undefined,
        link: undefined,
        name: undefined,
        number: 0,
        src: undefined,
        trkseg: undefined,
        type: undefined,
      },
      type: 'trk',
    });
  });
  test('db.put() generates an id for the trk if needed', async () => {
    const id = await putNewTrk({ gpx: 'gpxId' });
    expect(id).toEqual({ gpx: 'gpxId', trk: '00000' });
  });
  test('db.put() generates ids for both gpx and trk if needed', async () => {
    const id = await putNewTrk();
    expect(id).toEqual({ gpx: '0', trk: '00000' });
  });
});
